type_hinting_mapping = {
    "str": "string",
    "int": "number",
    "float": "number",
    "bool": "boolean"
}
